#
# spec file for package lsd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lsd
Version:        1.1.5
Release:        1.2
Summary:        Ls command with a lot of pretty colors and some other stuff
License:        Apache-2.0
URL:            https://crates.io/crates/lsd
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging

%description
Ls command with a lot of pretty colors and some other stuff.

%prep
%autosetup -a1

%build
%{cargo_build} --all

%install
%cargo_install

%files
%license LICENSE
%doc README.md
%{_bindir}/lsd

%changelog
* Tue Aug 20 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.1.4+1.1.5:
  * Fixed misaligned outputs and unicode-width dependency version.
  * add subtitle/closed caption icons.
* Mon Aug 19 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.1.3:
  * ❤️ update warp logo with linux support.
  * add blender icons.
  * Fix clap doc-comment.
  * Fix hint stating wrong permissions option.
* Mon Mar 25 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.1.2:
  * No changelog was made available.
* Sat Mar 23 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.1.1:
  * Parse hex colors in themes.
  * Add configuration and CLI options.
  * Add support for --literal flag and literal entry in config.
  * ✨ add disable option for permission.
  * 🔨 🎨 put fish auto comp under vendor.
  * Fix literal flag not being recognized from config file.
  * add obj directory icon.
  * add and improve icons.
  * Adding some more icons for filenames and extensions.
  * Add PRQL.
  * Nim lang support.
  * change neovim to proper icon.
  * Add fennel support.
  * Add icons for .apng and .avif.
* Mon Aug 28 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.0.0:
  * Add complete color theming support for Git.
  * Add Git integration.
  * In keeping with the coreutils change, add quotes and escapes
    for necessary filenames.
  * Add support for icon theme.
  * Add icon for kt and kts.
  * Add many icons from https://github.com/Peltoche/lsd/issues/764.
  * Add support for localization.
  * Add icons for cjs, cts and mts.
  * Fix obsolete Nerd Font icons.
  * profile and .profile now share the same icon.
  * Make tox.ini files use the gear/settings icon.
  * Do not quote filename when piping into another program.
  * Handle dereference (-L) with broken symlink.
  * Avoid using Clap’s deprecated structs and functions.
  * Icon theme with overrides from config.
  * Incorrect colorizing with --size=bytes.
  * Color theme is now expected to be in $XDG/lsd/colors.yaml
    by default, Legacy behaviour (themes folder) is marked as
    deprecated but is still supported.
  * Version sort option -v, --versionsort has been updated
    to match GNU version sort logic, similar to ls -v and sort -V.
* Tue Sep 13 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.23.1:
  * Fix tab completion for paths in ZSH.
  * Fix POSIX-compatible exit status.
* Mon Sep  5 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.23.0:
  * Add icon for Zstandard.
  * Reduce the binary size and improve the performance.
* Sun Jun 12 2022 dead_mozay@opensuse.org
- Update to version 0.22.0:
  * Added more icons
  * Reverted some changes
  * One more icon
  * Subjective icon changes, and more additions - will revert if wanted
  * Added new filenames and extensions
  * Use shell icon for when file is exec and has no extension
  * chore: correct description in readme for hyperlink
  * Underline header instead of adding "-" characters on new line
  * Center block headers, add underline
  * Print block header if header flag and OneLine layout is set
  * Add --header flag
  * Removed redundant error message when using hyperlinks if file is a broken symlink
  * do not calculate total directory size unless it will be displayed
  * feat(Icons): show icon for files with Dockerfile extension
  * Add icons for HEIC, PEM and TOML
  * Fix hyperlink display
  * Add --hyperlink flag
  * fix context positioning
  * display security label/context
  * add access control indicators
  * Fix some flaky integration tests
  * Fix a CI warning for window runs
  * Add `--permission octal` to show permissions in octal
  * Don't automatically dereference symlinks in tree/recursive
  * Add icon for AppleScript
  * Add icon for Adobe Illustrator files
  * Icons: added magnet and torrent
  * Remove incorrect comments in no_sort test
  * Rename unsorted flag to no-sort
  * Add unit tests for unsorted flag
  * Update man page with -U option
  * Add "do not sort" option
  * Fix clippy lints from rust upgrade
  * Change icon from 0xE5FC to 0xE615
  * GPG: Sign commit
  * Add --group-directories-first as an alias for --group-dirs=first
* Sun Jan 16 2022 dead_mozay@opensuse.org
- Update to version 0.21.0:
  * Add a note about default theme value in test
  * theme: :memo: :sparkles: add docs for partial theme
  * clippy: :art: :fire: drop not used lint
  * theme: :mag: :hammer: update tests to fit optional theme items
  * theme: :hammer: fallback to default theme if item missed
  * theme: :sparkles: add default and update the others optional
  * made the group-dirs flag require a value
  * done requested changes
  * retrigger tests for issue #582
  * faq: :sparkles: add putty/kitty icon render faq
  * Allow human-readable to be set multiple times
  * Exclude windows and non-x86_64 for bad_time as it overflows on those
  * Try reducing bad year count a bit, as it breaks on some platforms
  * Redo "Bad" enum as Invalid without internal data
  * Remove lots of returns from new code
  * Cope with chrono panics due to weird dates
  * Use a full string literal for MSRV 1.43.1 compatibility
  * Allocate owner and group strings on match, simplified string formatting
  * Accidentally shadowed a variable out of scope instead of mutating it
  * Display "-" instead of "-\-" by handling the error immediately
  * Blank out the SID instead of reporting as a long string (unidentified)
  * Better wording on the SID Lookup comment
  * Report unidentified if we cannot determine the security identifier
  * Add support for 'mi' missing symlink target LS_COLORS value.
  * theme: :hammer: try yml if yaml theme file not found
  * theme: :hammer: use dark color for default theme
  * :hammer: use lscolors for filename only, skip from theme configure
  * theme: :hammer: not deserialize no color and no lscolors from config
  * :memo: add filename coloring explanation between LS_COLOR and theme
  * config: :hammer: user do not have to config yaml extension for theme
  * theme: :hammer: use `themes` dir for themes configurations
  * build: :arrow_up: update dependency to deserialize color
  * :fire: get rid of ansi term in all code
  * :memo: :hammer: update readme to corssterm color
  * :sparkles: done use crossterm to impl theme, functionally works
  * theme: :art: :memo: update readme, change log, error log
  * color: :sparkles: add parse theme file
  * log: :doc: unique error output and update comment to fit config
  * config: :hammer: using target enum and vec string for config options
  * clippy lint: avoid manual implementation of Option
  * Change changelog entry format
  * Remove unnecesary `return`
  * Add NO_COLOR env support
  * Add .mjs extension (ESM)
  * Remove unnecessary use of read_link
  * Split over 2 lines
  * Change according to review feedback
  * Clarify custom date format string
  * add man page entry
  * correctly parsing custom config file arg. match
  * add config-file arg match
  * Add Link
  * Add F# icons
  * display/tree: :hammer: add space for better tree display
  * display: :art: delete tree color and apply review
  * display/tree: :sparkles: show tree edge at first column when no name block
  * display/tree: :hammer: detect all subdir size width when tree
  * display/tree: :hammer: fix misaligned when tree, add color to tree edge
  * display/tree: :art: show tree edge before name block
  * Add separator to sample config file vol.2
  * Add separator to sample config file.
  * Update classic help message
  * Use size bytes when in classic mode
  * Preparation changelog for new development
  * Add explicit sign-tag to release config
* Sun Mar  7 2021 dead_mozay@opensuse.org
- Update to version 0.20.1:
  * Update changelog.md for patch release
  * Remove tree test with --all
  * Fix test involving config file for sorting
  * Fix arg value parsing for flags that allow multiple input
  * Fix sorting with almost-all flag and a folder
  * display/tree: :mag: :sparkles: add test for tree with all not show self
  * display/tree: :hammer: not showing . and .. when tree with all
  * Adding lsd man page in markdown format
  * Changed INodeCount to Links
  * Fix for #407: Show number of hardlinks for lsd -l
  * Remove locale time style
  * Use recent date format for files older than 6 months
  * Add test cases for iso and locale formatting
  * Fix iso and locale time styles for older elements
  * Fix and test iso and locale time styles
  * Fix varying output lengths of inodes in integration test
  * Add test cases for order of precedence
  * Invert order of flag parsing to return early
  * Change order of flag parsing to arg -> env -> config
  * Fix error message for compatibility with previous version
  * Use chrono crate instead of time, fix date time formatting
  * Implement parsing date format from TIME_STYLE environment
  * Add a custom test case for the icon_separator
  * Add example for separator to example config
  * Change name 'spacing' to 'separator'
  * Remove unnecessary comment
  * Add simple test for IconSpacing
  * Remove `--icon-spacing` cli flag
  * Fix copied comments of the IconSpacing methods
  * Remove unused ICON_SPACING
  * Fix test by appending `" ".to_string()` to Icons::new calls
  * Add `--icon-spacing` flag and `icon.spacing` config option
  * respect blocks passed without long from cli
  * add pull request template
  * prepare changelog for new cycle
* Sun Dec 13 2020 dead_mozay@opensuse.org
- Update to version 0.19.0+0:
  * test: :mag: :hammer: make test name more clear, add reverse sort false
  * config: :hammer: :art: update code consistency due to review
  * log: :memo: unique error output and update comment to fit config
  * config: :hammer: using target enum and vec string for config options
  * config: :hammer: print error when config file error
  * config,flag: :hammer: refactor flag using serd yaml config
  * config file: :hammer: uniq file and serde yaml parsing
  * config: :hammer: refactor read config by name
  * use existing display and layout
  * don't follow symlinks with tree -d
  * Implement `lsd --tree -d`
  * Apply suggestions from code review
  * Make all known filenames & extensions lower-case and always match by lower-cased name
  * Add case-insensitive matching of known filenames and extensions
  * renamed to .jl extension
  * Added julia icon for .jl files
  * :hammer: move symlink arrow to root level
  * :hammer: change styles to styling
  * styling: :hammer: move symlink arrow to styling mod and use styling
  * update docs for symlink arrow
  * style: add config for symlink arrow
  * readd removed line
  * icon: :sparkles: add ttc font file
  * change macro to function in test
  * add version sort, group name in gid, panic by invalid utf-8
  * move how to show invalid utf-8 to FAQ
  * tidy up matches into maps
  * skip extension if no ext found
  * dep: :arrow_up: :bug: fix group name in gid
  * Add more archive icons
  * Remove duplicate line
  * Adds sort flag
  * Reword ignore config option
  * Add ability to configure default options with file
  * sort: :sparkles: add version sort
  * use last sort flag for sort
  * Add support for extension sort.
  * post release updates to changelog
  * Use vec of function pointers over sorting closure.
  * Refactor dirlike into FileType.
  * Cache sorter on Core.
  * Create closure to do sorting.
* Mon Aug 31 2020 dead_mozay@opensuse.org
- Update to version 0.18.0+0:
  * fix long listing for symlinkd dirs
  * show contents for symlink folders(fix #345)
  * :art: delete install via snap, add badges
  * do not expand sylink in grid display
  * arg: :sparkles: add support for dereference
  * add tests for special chars in filename
  * escape special chars in filename
  * fix regression causing size short to have space
  * fix file version
  * update windows FileType
  * refactor symlink check into FileType
  * minor refactor of return value
  * fix icon mistake
  * change yaml icon to indicate data like json and avro
  * change symlink file to match symlink dir (octicons)
  * change to actual symlink icon
  * unnecessary dots
  * sort symlinks appropriatelt with dirs/files
  * implement for windows too
  * change windows struct def
  * tidy comments
  * fix panic on broken symlinks; display as file
  * detect if symlink is_dir and show different icon: 
  * Added missing "can" to the text.
  * Improve help for '--ignore-glob" argument
  * Added spaces instead of tabs
  * added music icon for opus filetype
  * use name as file name when file name None
  * make not using canonical path when make parent path
  * remove canonicalize in relative_name function and add None Display Option
  * change parameter of windows file permission utility function
  * print . when path is same with base path
  * replace icon concat with format
  * remove redundent edits
  * add relative path function
  * remove current/parent display option
  * create display option of name
  * remove name property from Name struct
  * add wmv/wma icons and some playlist icons
  * change toolchain of style job into RUST_MIN_SRV
  * One lock icon to rule them all
  * Fix the icon for "ini"
  * Remove unneeded import to make clippy happy
  * Update terminal_size dependency to v0.1.12
* Wed Apr 15 2020 dead_mozay@opensuse.org
- Update to version 0.17.0+0:
  * *: :art: add newline to each print error
  * fix err description deprecated
  * delete fs canonicalize for show broken softlink without error
  * added csharp, sln and razor icons
  * revert the match to if else for blocks
  * inode: :art: update the inode help msg
  * args/inode: :hammer: inode work with long
  * test: add inode args integration test
  * args: :sparkles: add inode(i) args for showing inode,name
* Wed Apr 15 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
